;****************************************************************************************
;                                                                             
;    Filename:  KS01080 GLCD Driver for Pic18F4520        			          
;	 =============================================             				  
;																			  
;																			  
;																			  
;																			  
;   See Page 13 of the KS Datasheet for an explanation of the Control Codes	  



;****************************************************************************************
;
;	Processor Type
;	==============

			LIST P=18F4520,r=hex,n=80,x=off,st=off
			errorlevel -302		; no bank warnings

			#include <P18F4520.INC>	



;****************************************************************************************
; 
;	Configuration bits 
;	==================
  
; specified here are changes to the .inc file defaults

 CONFIG OSC=INTIO67, PWRT=ON, BOREN=OFF, WDT=OFF, MCLRE=ON, LPT1OSC=OFF, PBADEN=OFF
 CONFIG LVP=OFF, XINST=OFF, DEBUG=OFF, CCP2MX=PORTBE



;****************************************************************************************
;
;  Definitions
;  ===========

#define     KS0108_data     PORTD           ; LCD data bits (port wired to D0-D7) - in this case port D
#define		KS0108_tris     TRISD           ; LCD data direction - This is TRIS register for KS0108_data port
#define		KS0108_RST		PORTB, 5	  	; LCD system Reset
#define     KS0108_E        PORTB, 4        ; LCD E clock (pin wired to E line)
#define     KS0108_RW       PORTB, 3        ; LCD read/write line (pin wired to RW line)
#define     KS0108_RS       PORTB, 2        ; LCD register select line (pin wired to RS line)
#define		KS0108_CS1      PORTB, 0        ; CS1 line (pin wired to CS1 line)
#define		KS0108_CS2      PORTB, 1        ; CS2 line (pin wired to CS2 line)
#define		KS0108_RST_DIR	TRISB, 5		; LCD system Reset TRIS bit
#define     KS0108_E_DIR    TRISB, 4        ; E  line associated TRIS bit
#define     KS0108_RW_DIR   TRISB, 3        ; RW line associated TRIS bit
#define     KS0108_RS_DIR   TRISB, 2        ; RS line associated TRIS bit
#define 	KS0108_CS1_DIR  TRISB, 0        ; CS1 line associated TRIS bit
#define 	KS0108_CS2_DIR  TRISB, 1        ; CS2 line associated TRIS bit
#define 	MCUCLK          Nop4            ; delay time for data settling: select Nop4 for CPUCLK > = 20 MHZ else select Nop0


;******************************************************************************
;
;	Variables
;	=========


	cblock  0x000

	d1									; delay routine work files
	d2
	d3				
	GWORK1								; glcd work files
	GWORK2
	GWORK3
	GTBLU								; table pointer copies
	GTBLH
	GTBLL
	GCOLHIGH							
	GCOLLOW
	G1CHAR
	TABWORK								; tables work file
	KS0108_out                     		; var to put in data to be displayed
 	KS0108_X                        	; X pos to turn on pixel
 	KS0108_Y                         	; Y POS TO TURN ON PIXEL
 	KS0108_COL                          ; RAW    
	KS0108_RAW                        	; COL
 	KS0108_busyflag               		; status flags (local)
 	KS0108_IN                           ; data input from KS0108
    xpagenum							; X Page Number
    ycolnum								; Y Column Number
  	FONT								; font to be used

	endc





;******************************************************************************
;
;	Reset vector
;	============

		ORG	0x0000

bootup	goto	main						;go to start of main code

		
		ORG	0x0008							; High Priority Interrupts
		bra	ISR_HIGH

		ORG	0x0018							; Low Priority Interrupts
		bra	ISR_LOW



;******************************************************************************
;
;	High Priority ISR Routine
;   =========================

ISR_HIGH	retfie	FAST


;******************************************************************************
;
;	Low Priority ISR Routine
;   =======================
										
ISR_LOW		retfie	FAST							



;******************************************************************************
;
;	Start of main program
;	=====================

; initialisation of system, clear RAM , setup i/o ports



main		movlw	b'01100010'				; Internal osc to 4meg 
			movwf	OSCCON					; to allow display to be seen working
 											; SEE SLO-MO OSCCON LATER

	
ramclr		movlb	D'1'					; define bank1, so it and bank 0/15 (access) 
											; can be addressed without banking


 			clrf	FSR1H					; FSR routine to clear ram banks 0 -4 only
			clrf	FSR1L		
clrram		clrf	POSTINC1				; clear location and inc
 			movlw	0x05					; now in bank5 ?
 			subwf	FSR1H,W
 			bnz		clrram					; carry on clearing if not at bank5
	

			
ports		clrf	PORTA
			clrf	PORTB
			clrf	PORTC
			clrf	PORTD
			clrf	PORTE

			movlw	b'00001101'				; set portA 0 & 1 as adc input bit 7 rjust
			movwf	ADCON1					; by loading value to adcon1 reg
			movlw	b'00011011'				; set trisa direction is input
			movwf	TRISA					; bit0,1 adc,   bit2,5,6,7 DO,  bit3,4, DI 

			movlw	b'00000000'				; set portB as Outputs
			movwf	TRISB

			movlw	b'00110000'				; set portC as Outputs,  BITS 4 and 5 input for SPI
			movwf	TRISC

			movlw	b'11111111'				; set portD as Input
			movwf	TRISD

			movlw	b'00001111'     		; set portE as Inputs
			movwf	TRISE



; ***************************************************************************************
;
;	Macros
;	======
;


;  Macro for calling required Bitmap Image
;  =======================================

gimage		macro	bitmap
			movlw	high bitmap			 	; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper bitmap		 	; load font1 U address
			movwf	TBLPTRU					
 			movlw	low bitmap			 	; load font1 L address to tbptrL
			movwf	TBLPTRL
			
			call	gbmpget1				; routine to get data and write out image
			
			endm

;			Current Bitmap Images			eadog     - main dogl intro screen
;											eaupdown  - test menu up/down/accept





;  Macro for calling required Full screen of Text
;  ==============================================


g8lines 	macro	g8pages
			movlw	high g8pages			; load text H address to tblptrH
			movwf	TBLPTRH
			movlw	upper g8pages			; load text U address to tblptrU
			movwf	TBLPTRU			
  			movlw	low g8pages				; load text L address to tblptrL
			movwf	TBLPTRL	
			
			call	g8text

		   endm




;  Macro for calling One Page of Text
;  ==================================


goneline 	macro	g1pages,pagenum			; page number must be .00-.07 decimal
			movlw	high g1pages			; load text H address to tblptrH
			movwf	TBLPTRH
			movlw	upper g1pages			; load text U address to tblptrU
			movwf	TBLPTRU			
  			movlw	low g1pages				; load text L address to tblptrL
			movwf	TBLPTRL	
			movlw	b'10111000'				; specified Page No as 'BO'
			movwf	xpagenum
			movlw	pagenum					; adds in required page number
			addwf	xpagenum
			movf	xpagenum,W
		    call	KS0108commandW 
			call	gonetext

		   endm





;  Macro for Displaying One Character 
;  ==================================


; options  gchar .00  - .07, ( page num )   .0 - .8 .16 .24 .32 .40 .48 .56  - .120  (col num )


gchar 		macro   pagenum, column 		; page number must be .00-.07 dec
			movwf	G1CHAR	

			call	chip1on
			movlw	b'10111000'				; specified Page No as 'B8'
			movwf	xpagenum
			movlw	pagenum					; add macro pagenum
			addwf	xpagenum
			movf	xpagenum,W
		    call	KS0108commandW 

		    movlw 	0x40                	; load Dislay Start Line to 00
			movwf	ycolnum
			movlw	column					; add macro colnum
			addwf	ycolnum
			movf	ycolnum,W
		    call	KS0108commandW 	
				
		  	call	gonechar

	  	    endm




; ***************************************************************************************
;
;	GLCD DEMO ROUTINE			-   IN SLOW MOTION WITH 250K CLOCK BELOW
;	================
;
; ***************************************************************************************



glcdmain	call	delay500				; little delay to let glcd boot up
	
	
											; SLO-MO OSCCON
			movlw	b'00010010'				; Internal osc to 250k **************************REMOVE FOR FULL SPEED
			movwf	OSCCON					; to allow display to be seen working
 		


			call 	KS0108init             	; Initialise the Display

			movlw	0x01					; select font1
			movwf	FONT


display     movlw 	0xFF					; fill dispay	
 			movwf 	KS0108_out             
			call 	KS0108fill


			movlw 	0x00					; clear display	
 			movwf 	KS0108_out              
			call 	KS0108fill


			gimage	eadog					; Displays a Bitmap Image eadog

			call	delay1ms
			call	delay1ms
		

			movlw 	0x00					; clear dispay	
 			movwf 	KS0108_out              
			call 	KS0108fill

	
			movlw	0x01					; select  'normal' font
			movwf	FONT


			goneline	g1_menu, .03		; display 1 line of text

			call	delay1ms


			movlw	0x02					; select 'bold' font
			movwf	FONT


			movlw	'T'						; display 1 character of text
			movwf	G1CHAR					
			gchar  .03, .120
		
			call	delay1ms



			call 	KS0108fill				; clear display


			movlw	0x01					; select  'normal' font
			movwf	FONT


			g8lines	g8_mainmenu				; display 8 lines of text

			call	delay1ms
			call	delay1ms

			call 	KS0108fill				; clear display


			movlw	0x02					; select 'bold' font
			movwf	FONT


			g8lines	g8_mainmenu				; display 8 lines of text

			call	delay1ms
			call	delay1ms


			call 	KS0108fill				; clear display

			movlw	0x03					; select 'bold serif' font
			movwf	FONT


			g8lines	g8_mainmenu				; display 8 lines of text

			call	delay1ms



Lp			nop		
			goto	Lp





; ***************************************************************************************
; SUBROUTINES
; ===========


; ***************************************************************************************
;
;	TEXT ROUTINES
;   ==============		
;
;
; ***************************************************************************************
;
;	SUBROUTINE		Display all 8 "lines" (pages) of Text  
;   ==========      =====================================		



g8text 		call	chip1on
			clrf	GWORK3					; setup table and display text
			call	glcd_home
											; table pointer set up by macro
g8next_pb1	tblrd	*+            			; read table entry into TABLAT
			movlw	.8						; has the 8th CHARACTER been read 
			cpfslt	GWORK1					
			goto	g8ch2					; goto chip2 for 8-16 character

			movff	TBLPTRU,GTBLU			; save table pointer as overwritten
			movff	TBLPTRH,GTBLH			; by the font lookup
			movff	TBLPTRL,GTBLL
			movf	TABLAT,w      			; in W REG
			call	glcd_write_character	; get data and write out
		
			movff	GTBLU,TBLPTRU			; restore table pointer as overwritten
			movff	GTBLH,TBLPTRH			; by the font lookup
			movff	GTBLL,TBLPTRL							
			incf	GWORK1					; by 1 Character = 8 Columns
			goto	g8next_pb1

g8inc	
			call	chip1on					; page 2 done, so reset for next page loop
			clrf	GWORK1
			incf	xpagenum				; increment page
			movf	xpagenum,W
		    call	KS0108commandW 	   		 
			movlw 	0x40                	; on new page, so reset column to 00
   			call 	KS0108commandW     		 
			movlw	0xC0					; has page 7 been done
			cpfseq	xpagenum
			goto	g8next_pb1				; no - read next page of data

			return
		
			
	
g8ch2		call	chip2on
			movf	xpagenum,W				; load current page number to chip2
		    call	KS0108commandW 	   		 
			movlw 	0x40                	; on new page, so reset column to 00
   			call 	KS0108commandW 
		 	goto	g8send
g8rands
			tblrd	*+            			; read table entry into TABLAT
g8send	
			movff	TBLPTRU,GTBLU			; save table pointer as overwritten
			movff	TBLPTRH,GTBLH			; by the font lookup
			movff	TBLPTRL,GTBLL
			movf	TABLAT,w      			; in WREG
			call	glcd_write_character	; get data and write out

			movff	GTBLU,TBLPTRU			; restore table pointer as overwritten
			movff	GTBLH,TBLPTRH			; by the font lookup
			movff	GTBLL,TBLPTRL							
		

			incf	GWORK1	
			movlw	.16			 			; have 16 CHAARACTERS been outputted
			cpfseq	GWORK1		  		    
			goto	g8rands					; no - read next data byte

			bra		g8inc 

							
			
	

; ***************************************************************************************
;
;	SUBROUTINE		Display a Single Character
;   ==========      ==========================		

	
gonechar	movlw 	0x7F					; if col numbe greater than 7F then = chip2
			cpfsgt	ycolnum
			goto	gcharout
			
			call	chip2on					; is chip2 so set up x and y
  			movf	xpagenum,W
		    call	KS0108commandW 

			movlw	0x40					; sub h40 from page2 col value
			subwf	ycolnum
			movf	ycolnum,W
		    call	KS0108commandW 	

gcharout	movf	G1CHAR,W
   			call	glcd_write_character	; get data and write out
	
			return



; ***************************************************************************************
;
;	SUBROUTINE		Display One Page of Text  
;   ==========      ========================		

	
gonetext 	call	chip1on
			clrf	GWORK1					; setup table and display text
			movlw 	0x40           		    ; load Column start to 00
			movwf	ycolnum					; save in ycolnum
   			call 	KS0108commandW      



gnext_pb1	tblrd	*+           			; read table entry into TABLAT
			movlw	.8						; has the 8th CHARACTER been read 
			cpfslt	GWORK1					
			goto	g1ch2					; goto chip2 for 8-16 character

			movff	TBLPTRU,GTBLU			; save table pointer as overwritten
			movff	TBLPTRH,GTBLH			; by the font lookup
			movff	TBLPTRL,GTBLL
			movf	TABLAT,w      			; in WREG
			call	glcd_write_character	; get character converted and write out
		
			movff	GTBLU,TBLPTRU			; restore table pointer as overwritten
			movff	GTBLH,TBLPTRH			; by the font lookup
			movff	GTBLL,TBLPTRL							
		
			incf	GWORK1
			goto	gnext_pb1


				
g1ch2		call	chip2on
			movf	xpagenum,W				; load current page number to chip2
		    call	KS0108commandW 	   		 
			movlw 	0x40                	; on new page, so reset column to 00
   			call 	KS0108commandW 
		 	goto	g1send
g1rands
			tblrd	*+            			; read table entry into TABLAT
g1send	
			movff	TBLPTRU,GTBLU			; save table pointer as overwritten
			movff	TBLPTRH,GTBLH			; by the font lookup
			movff	TBLPTRL,GTBLL
			movf	TABLAT,w      			; in WREG
			call	glcd_write_character	; get data and write out

			movff	GTBLU,TBLPTRU			; restore table pointer as overwritten
			movff	GTBLH,TBLPTRH			; by the font lookup
			movff	GTBLL,TBLPTRL							
		
			incf	GWORK1	
			movlw	.16			 			; have 16 CHAARACTERS been outputted
			cpfseq	GWORK1		  		    
			goto	g1rands					; no - read next data byte

			return 


; ***************************************************************************************
;
;	SUBROUTINE		Write Text Strings
;   ==========      ==================		



glcd_write_character					 ; takes the character, looks up the 8 bytes of pixel data and sends out
			clrf	PRODL
			clrf	PRODH
			addlw	-.32			  	 ; subtract 32 to get value
			mullw	.8					 ; multipy  value by 8 to get offset value
										 ; result in PRODL AND PRODH
			movlw	.8					 ; preload data byte counter for 7 bits
			movwf	GWORK2
			bcf		STATUS,C			 ; clear carry bit


gfont1		movlw	0x01				; select required font
			cpfseq	FONT
			goto	gfont2
			movlw	high font1 			; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper font1			; load font1 U address
			movwf	TBLPTRU			
 			movlw	low font1			; load font1 L address to tbptrL
			movwf	TBLPTRL
			goto	gnextfd

gfont2		movlw	0x02				; select required font
			cpfseq	FONT
			goto	gfont3

			movlw	high font2 			; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper font2			; load font1 U address
			movwf	TBLPTRU			
 			movlw	low font2			; load font1 L address to tbptrL
			movwf	TBLPTRL
			goto	gnextfd
	
gfont3		movlw	high font3 			; load font1 H address to tbptrH
			movwf	TBLPTRH
			movlw	upper font3			; load font1 U address
			movwf	TBLPTRU			
 			movlw	low font3			; load font1 L address to tbptrL
			movwf	TBLPTRL

										 ; now update font1 pointers with the character offset
gnextfd		movf	PRODH,W				 ; add in any prodH offset value
			addwf	TBLPTRH,F

			movf	PRODL,W				 ; add ProdL with offset value
			addwf	TBLPTRL 
			btfsc	STATUS,C			 ; has add created a carry over
			incf	TBLPTRH,F			 ; yes, so add 1 to tbptrH


gnext_pbz	tblrd	*+             		 ;read table entry into TABLAT
			movf	TABLAT,w       		 ;in WREG
			call	KS0108writeW		 ; send data 
			decfsz	GWORK2
			goto	gnext_pbz			; go round to read and send out the next byte of the character
	 

			return




; ***************************************************************************************
;	BRYANS
;	SUBROUTINE		BitMap Table Read Sub   - Write out Bitmap Image
;	==========      ================================================


gbmpget1
			call	chip1on					; select chip1			

			call	glcd_home				; reset display to home position & clr GWORK1
											; which holds the Column position
		
gnext_rd	
			tblrd	*+            			; read table entry into TABLAT
			movlw	d'64'					; if column is above 64 then do not display data
			cpfslt	GWORK1					; as it is for chip2 65 - 128
			GOTO	g2on
			movf	TABLAT,w      			; in WREG
			call	KS0108writeW			; send data 
gskip		
			incf	GWORK1	
			goto	gnext_rd				; no - read next data byte

gInc		call	chip1on
			clrf	GWORK1					; yes - so increment page and set up 
			incf	xpagenum				; increment page
			movf	xpagenum,W
		    call	KS0108commandW 	   		 
			movlw 	0x40                	; on new page, so reset column to 00
   			call 	KS0108commandW     		 
			movlw	0xC0					; has page 7 been done
			cpfseq	xpagenum
			goto	gnext_rd				; no - read next page of data
			call	chip1on

			return

		
g2on		call	chip2on
			movf	xpagenum,W
		    call	KS0108commandW 	   		 
			movlw 	0x40                	; on new page, so reset column to 00
   			call 	KS0108commandW 
			bra		g2send
		 
g2rands
			tblrd	*+            			; read table entry into TABLAT
g2send		movf	TABLAT,w      			; in WREG
			call	KS0108writeW			; send data 
			incf	GWORK1	
			movlw	d'128'			 		; have 128 columns been READ
			cpfseq	GWORK1		  		    
			goto	g2rands					; no - read next data byte
					
			bra		gInc 




; *****************************************************************************  
;
;   SUBROUTINE	 Glcd Home Position  - Loads the default addresses as 00 and clears work files
; 	==========   ==================

glcd_home	clrf	GWORK1

			movlw	0XB8				 ; load Page value to 00
			movwf	xpagenum
		    call	KS0108commandW 	    

		    movlw 	0xC0                ; load Dislay Start Line to 00
		    call	KS0108commandW 	    
		
  			movlw 	0x40                ; load Column start to 00
			movwf	ycolnum				; save in ycolnum
   			call 	KS0108commandW      

			return



; *****************************************************************************  
;
;	SUBROUTINE	Initialise the Display
; 	==========	=====================


KS0108init  bcf		KS0108_RST_DIR			;Initialise control port
 		    bcf		KS0108_E_DIR  
            bcf		KS0108_RW_DIR
            bcf 	KS0108_RS_DIR
            bcf 	KS0108_CS1_DIR
            bcf		KS0108_CS2_DIR
            clrf	KS0108_tris				; *	so providing option to use other two bits
            bcf     KS0108_E
            bcf     KS0108_RW
            bcf     KS0108_RS
            bcf     KS0108_CS1
            bcf     KS0108_CS2
            clrf    KS0108_data			     

											; Reset the Glcd
		    call	Nop8					; little pause with RST at Low - ie Reset
		    bsf		KS0108_RST				; turn RST high
		    call	Nop8 					; little pause to settle
			
			call	chip1on					; enable chip1  ( only one chip can be on at a time )
				
		    movlw 	0x3F                    ; Send out Command 3F to turn display On
		    call 	KS0108commandW       

		    movlw 	0xC0                    ; Send out Command C0 to Set the dispay start line to 0
		    call	KS0108commandW 			; ie the horizonatal row from 0 -63

		    call	chip2on					; repeats the exercise for controller 2
  		  		
  		    movlw   0x3F						
            call    KS0108commandW
            movlw   0xC0
            call    KS0108commandW			
          
			call	chipsoff  				; deselects both controllers
           
		    movlw   0x00					; write 00 to all location to clear the displays using the 'fill' subroutine
 		    movwf   KS0108_out              
 		    call    KS0108fill    
             
 		    return




; *****************************************************************************  
;
;	SUBROUTINE	KS0108fill - fill GLCD whith data stored in KS0108_out 
;	 =========	==========
;

KS0108fill  call	chip1on					; Select chip1

											
chip2_entry call	glcd_home				; Send commands to reset display 

col_loop	movf 	KS0108_out ,W           ; write out the data to the current page and column locations  
   			call 	KS0108writeW            ; each data write op increments the displays internal column counter - not ours !
			    
		    incf	ycolnum					; inc ycolnum and test if at the end of the row
		    movlw	0x7F
		    cpfsgt	ycolnum
		    goto	col_loop
	
   			movlw 	0x40                    ; rest colnum to 0x40
			movwf	ycolnum					; save in ycolnum
     		call 	KS0108commandW          ; ReSet Column Start to 00

			movlw	0xBF					; is page number 0x07
			cpfseq	xpagenum
			goto	page_loop				; no -  inc page and loop again
			
		    goto	fillchip2				; yes  - repeat loop but on chip2

page_loop	incf	xpagenum				; inc pagenum for next loop
			movf	xpagenum,W 				; save in xpagenum
 		    call 	KS0108commandW          ; Set Page Number +1
			goto	col_loop


fillchip2	btfss	KS0108_CS2              ; if controller1 selected goto controller 2, else end
   			goto 	fillend

			call	chip2on           		; selects controller 2
   			
			goto 	chip2_entry             ; repeats whole loop 

fillend		movlw 	0xC0					; reset Display Start Line
  		    call 	KS0108commandW

   			call	chipsoff 				; deselect controller
   
   			return



;***********************************************************************************************************************
;
;	SUBROUTINE	Write a Command to KS0108
;	==========	=========================


KS0108command movf  KS0108_out,W  				; entry with data in _out

KS0108commandW                 			 		; entry with data in WREG 
		 	bcf 	KS0108_RS                   ; clear RS line
   			bcf 	KS0108_RW                   ; clear RW line
   			bsf 	KS0108_E                    ; Enable high to lock command lines status
   			movwf 	KS0108_data            	    ; data on D0-D7
   			call 	MCUCLK                      ; wait - settling time
  			bcf 	KS0108_E                    ; Enable low
  		    nop                                 ; 1 cycle settiling time
;   		call KS0108_ready          	        ; check busy flag ( if clock is less than 12 MHz it shall be omitted)
 
		    return



;************************************************************************************************
;
;	SUBROUTINE	Write Data to KS0108    
;   =========	====================


KS0108write movf 	KS0108_out,W

KS0108writeW
  		    bsf 	KS0108_RS				; set RS high to denote incoming Data
   			bcf 	KS0108_RW
   			bsf 	KS0108_E
   			movwf 	KS0108_data
   			call 	MCUCLK
   			bcf 	KS0108_E
   			bcf 	KS0108_RS
			nop
; 		    call KS0108_ready 				; check busy flag ( if clock is less than 12 MHz it shall be omitted)

   			return




;******************************************************************************************************
;
;	SUBROUTINE	Chip Selects
;   ==========	===========


chip1on		bcf		KS0108_CS1				; Select driver chip1 by bits CS1 and CS2
  		    bsf 	KS0108_CS2	
			return	

chip2on		bsf		KS0108_CS1				; Select driver chip2 by bits CS1 and CS2
  		    bcf 	KS0108_CS2	
			return

chipsoff	bcf		KS0108_CS1				; Select driver, both off by bits CS1 and CS2
  		    bcf 	KS0108_CS2	
			return




;******************************************************************************************************
;
;	SUBROUTINE	Wait cycle (  - ORIGINAL USERS DELAY ROUTINES
;   ==========  ==========

Nop20
  		 	nop
   			nop
   			nop
   			nop
   			nop
   			nop
   			nop
   			nop
   			nop
   			nop
   			nop
  	        nop
  		    nop
Nop8
   			nop
   			nop
   			nop
   			nop
Nop4
   			nop
   			nop
   			nop
   			nop
Nop0
   			return




; ***************************************************************************************
;
;	SUBROUTINE		Delays based on 4meg osc
;   ==========      ========================		



delay1ms	movlw	0xC6				 ; delay 1ms
			movwf	d1
			movlw	0x15				;  *** 1ms = 0X01  ** CHANGED FOE SLOW MO DISPLAY
			movwf	d2
dly1ms		decfsz	d1, f
			goto	dly1msa
			decfsz	d2, f
dly1msa		goto	dly1ms
			nop							
			nop
			nop			
		
			return



delay250	movlw	d'250'				 ; delay 250 ms 
			movwf	d1
dly1		 movlw	0xC7
			movwf	d2
			movlw	0x01
			movwf	d3
Delay_0
			decfsz	d2, f
			goto	dly2
			decfsz	d3, f
dly2		 goto	Delay_0
			decfsz	d1	,f
			goto	dly1

			return



delay500	call	delay250			 ; delay 500ms
			call	delay250

			return



delay1sec	call	delay500			 ; delay 1sec
			call	delay500	

			return



delay5sec	call 	delay1sec			 ; delay 5sec
			call 	delay1sec
			call	delay1sec
			call	delay1sec
			call	delay1sec

			return




; ***************************************************************************************
; ***************************************************************************************
;
;	DATA FILES
;   ==========	
;



; ***************************************************************************************
;
;	TEXT STRINGS
;   ===========
;
;	g8_ prefix for all 8 pages of data
;   g1_ prefix for just 1 page of data

g8_data1
		db  "ALTITUDE    200m"
		db	"GPS 24.5N  34.5W"
		db	"PITCH     2 DEG "
		db	"YAW       3 DEG "
		db	"FUEL     23 MINS"
		db	"GYRO            "
		db	"BATTERY         "
		db	"                "



g8_mainmenu

		db  "TEMPERATURE     "
		db	"LIGHTS          "
		db	"FEED TIMER      "
		db	"TOP UP          "
		db	"ALARM           "
		db	"WAVEMAKER       "
		db	"CHILLERS        "
		db	"KS0108  DEMO END"


g1_menu 
		db	"ONE LINE OF TEX_ ", 0



; ***************************************************************************************
;
;	FONTS
;   =====


;lash unsigned char English Standard8x8[] = {

font1

;	Mono Spaced - Normal

	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ;32/ -->  
	db	0x00,0x00,0x4F,0x00,0x00,0x00,0x00,0x00 ;33/ --> !
	db	0x00,0x07,0x00,0x07,0x00,0x00,0x00,0x00 ;34/ --> "
	db	0x00,0x14,0x7F,0x14,0x7F,0x14,0x00,0x00 ;35/ --> #
	db	0x00,0x24,0x2A,0x7F,0x2A,0x12,0x00,0x00 ;36/ --> $
	db	0x00,0x23,0x13,0x08,0x64,0x62,0x00,0x00 ;37/ --> %
	db	0x00,0x36,0x49,0x55,0x22,0x40,0x00,0x00 ;38/ --> &
	db	0x00,0x00,0x05,0x03,0x00,0x00,0x00,0x00 ;39/ --> '
	db	0x00,0x1C,0x22,0x41,0x00,0x00,0x00,0x00 ;40/ --> (
	db	0x00,0x41,0x22,0x1C,0x00,0x00,0x00,0x00 ;41/ --> )
	db	0x00,0x14,0x08,0x3E,0x08,0x14,0x00,0x00 ;42/ --> *
	db	0x00,0x08,0x08,0x3E,0x08,0x08,0x00,0x00 ;43/ --> +
	db	0x00,0x00,0x28,0x18,0x00,0x00,0x00,0x00 ;44/ --> ,
	db	0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x00 ;45/ --> -
	db	0x00,0x30,0x30,0x00,0x00,0x00,0x00,0x00 ;46/ --> .
	db	0x00,0x20,0x10,0x08,0x04,0x02,0x00,0x00 ;47/ --> /
	db	0x00,0x3E,0x51,0x49,0x45,0x3E,0x00,0x00 ;48/ --> 0
	db	0x00,0x00,0x42,0x7F,0x40,0x00,0x00,0x00 ;49/ --> 1
	db	0x00,0x42,0x61,0x51,0x49,0x46,0x00,0x00 ;50/ --> 2
	db	0x00,0x21,0x41,0x45,0x4B,0x31,0x00,0x00 ;51/ --> 3
	db	0x00,0x18,0x14,0x12,0x7F,0x10,0x00,0x00 ;52/ --> 4
	db	0x00,0x00,0x27,0x45,0x45,0x45,0x39,0x00 ;53/ --> 5
	db	0x00,0x3C,0x4A,0x49,0x49,0x30,0x00,0x00 ;54/ --> 6
	db	0x00,0x01,0x71,0x09,0x05,0x03,0x00,0x00 ;55/ --> 7
	db	0x00,0x36,0x49,0x49,0x49,0x36,0x00,0x00 ;56/ --> 8
	db	0x00,0x06,0x49,0x49,0x29,0x1E,0x00,0x00 ;57/ --> 9
	db	0x00,0x00,0x36,0x36,0x00,0x00,0x00,0x00 ;58/ --> :
	db	0x00,0x00,0x56,0x36,0x00,0x00,0x00,0x00 ;59/ --> ;
	db	0x00,0x08,0x14,0x22,0x41,0x00,0x00,0x00 ;60/ --> <
	db	0x00,0x24,0x24,0x24,0x24,0x24,0x00,0x00 ;61/ --> =
	db	0x00,0x00,0x41,0x22,0x14,0x08,0x00,0x00 ;62/ --> >
	db	0x00,0x02,0x01,0x51,0x09,0x06,0x00,0x00 ;63/ --> ?
	db	0x00,0x32,0x49,0x79,0x41,0x3E,0x00,0x00 ;64/ --> @
	db	0x00,0x7E,0x11,0x11,0x11,0x7E,0x00,0x00 ;65/ --> A
	db	0x00,0x7F,0x49,0x49,0x49,0x36,0x00,0x00 ;66/ --> B
	db	0x00,0x3E,0x41,0x41,0x41,0x22,0x00,0x00 ;67/ --> C
	db	0x00,0x7F,0x41,0x41,0x22,0x1C,0x00,0x00 ;68/ --> D
	db	0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x00 ;69/ --> E
	db	0x00,0x7F,0x09,0x09,0x09,0x01,0x00,0x00 ;70/ --> F
	db	0x00,0x3E,0x41,0x49,0x49,0x3A,0x00,0x00 ;71/ --> G
	db	0x00,0x7F,0x08,0x08,0x08,0x7F,0x00,0x00 ;72/ --> H
	db	0x00,0x00,0x41,0x7F,0x41,0x00,0x00,0x00 ;73/ --> I
	db	0x00,0x20,0x40,0x41,0x3F,0x01,0x00,0x00 ;74/ --> J
	db	0x00,0x7F,0x08,0x14,0x22,0x41,0x00,0x00 ;75/ --> K
	db	0x00,0x7F,0x40,0x40,0x40,0x40,0x00,0x00 ;76/ --> L
	db	0x00,0x7F,0x02,0x0C,0x02,0x7F,0x00,0x00 ;77/ --> M
	db	0x00,0x7F,0x04,0x08,0x10,0x7F,0x00,0x00 ;78/ --> N
	db	0x00,0x3E,0x41,0x41,0x41,0x3E,0x00,0x00 ;79/ --> O
	db	0x00,0x7F,0x09,0x09,0x09,0x06,0x00,0x00 ;80/ --> P
	db	0x3E,0x41,0x51,0x21,0x5E,0x00,0x00,0x00 ;81/ --> Q
	db	0x00,0x7F,0x09,0x19,0x29,0x46,0x00,0x00 ;82/ --> R
	db	0x00,0x46,0x49,0x49,0x49,0x31,0x00,0x00 ;83/ --> S
	db	0x00,0x01,0x01,0x7F,0x01,0x01,0x00,0x00 ;84/ --> T
	db	0x00,0x3F,0x40,0x40,0x40,0x3F,0x00,0x00 ;85/ --> U
	db	0x00,0x1F,0x20,0x40,0x20,0x1F,0x00,0x00 ;86/ --> V
	db	0x00,0x3F,0x40,0x60,0x40,0x3F,0x00,0x00 ;87/ --> W
	db	0x00,0x63,0x14,0x08,0x14,0x63,0x00,0x00 ;88/ --> X
	db	0x00,0x07,0x08,0x70,0x08,0x07,0x00,0x00 ;89/ --> Y
	db	0x00,0x61,0x51,0x49,0x45,0x43,0x00,0x00 ;90/ --> Z
	db	0x00,0x7F,0x41,0x41,0x00,0x00,0x00,0x00 ;91/ --> [
	db	0x00,0x15,0x16,0x7C,0x16,0x15,0x00,0x00 ;92/ --> \
	db	0x00,0x41,0x41,0x7F,0x00,0x00,0x00,0x00 ;93/ --> ]
	db	0x00,0x04,0x02,0x01,0x02,0x04,0x00,0x00 ;94/ --> ^
	db	0x00,0x40,0x40,0x40,0x40,0x40,0x00,0x00 ;95/ --> _
	db	0x00,0x01,0x02,0x04,0x00,0x00,0x00,0x00 ;96/ --> `
	db	0x00,0x20,0x54,0x54,0x54,0x78,0x00,0x00 ;97/ --> a
	db	0x00,0x7F,0x44,0x44,0x44,0x38,0x00,0x00 ;98/ --> b
	db	0x00,0x38,0x44,0x44,0x44,0x00,0x00,0x00 ;99/ --> c
	db	0x00,0x38,0x44,0x44,0x48,0x7F,0x00,0x00 ;100/ --> d
	db	0x00,0x38,0x54,0x54,0x54,0x18,0x00,0x00 ;101/ --> e
	db	0x00,0x10,0x7E,0x11,0x01,0x02,0x00,0x00 ;102/ --> f
	db	0x00,0x0C,0x52,0x52,0x52,0x3E,0x00,0x00 ;103/ --> g
	db	0x00,0x7F,0x08,0x04,0x04,0x78,0x00,0x00 ;104/ --> h
	db	0x00,0x00,0x44,0x7D,0x40,0x00,0x00,0x00 ;105/ --> i
	db	0x00,0x20,0x40,0x40,0x3D,0x00,0x00,0x00 ;106/ --> j
	db	0x00,0x7F,0x10,0x28,0x44,0x00,0x00,0x00 ;107/ --> k
	db	0x00,0x00,0x41,0x7F,0x40,0x00,0x00,0x00 ;108/ --> l
	db	0x00,0x7C,0x04,0x18,0x04,0x78,0x00,0x00 ;109/ --> m
	db	0x00,0x7C,0x08,0x04,0x04,0x78,0x00,0x00 ;110/ --> n
	db	0x00,0x38,0x44,0x44,0x44,0x38,0x00,0x00 ;111/ --> o
	db	0x00,0x7C,0x14,0x14,0x14,0x08,0x00,0x00 ;112/ --> p
	db	0x00,0x08,0x14,0x14,0x18,0x7C,0x00,0x00 ;113/ --> q
	db	0x00,0x7C,0x08,0x04,0x04,0x08,0x00,0x00 ;114/ --> r
	db	0x00,0x48,0x54,0x54,0x54,0x20,0x00,0x00 ;115/ --> s
	db	0x00,0x04,0x3F,0x44,0x40,0x20,0x00,0x00 ;116/ --> t
	db	0x00,0x3C,0x40,0x40,0x20,0x7C,0x00,0x00 ;117/ --> u
	db	0x00,0x1C,0x20,0x40,0x20,0x1C,0x00,0x00 ;118/ --> v
	db	0x00,0x1E,0x20,0x10,0x20,0x1E,0x00,0x00 ;119/ --> w
	db	0x00,0x22,0x14,0x08,0x14,0x22,0x00,0x00 ;120/ --> x
	db	0x00,0x06,0x48,0x48,0x48,0x3E,0x00,0x00 ;121/ --> y
	db	0x00,0x44,0x64,0x54,0x4C,0x44,0x00,0x00 ;122/ --> z
	db	0x00,0x08,0x36,0x41,0x00,0x00,0x00,0x00 ;123/ --> {
	db	0x00,0x00,0x00,0x7F,0x00,0x00,0x00,0x00 ;124/ --> |
	db	0x00,0x41,0x36,0x08,0x00,0x00,0x00,0x00 ;125/ --> }
	db	0x00,0x08,0x08,0x2A,0x1C,0x08,0x00,0x00 ;126/ --> ~
	db	0x00,0x08,0x1C,0x2A,0x08,0x08,0x00,0x00 ;127/ --> 



font2

;	Mono Spaced - Bold

	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 ;32/ -->  
	db	0x00,0x00,0x06,0xDF,0xDF,0x06,0x00,0x00 ;33/ --> !
	db	0x00,0x06,0x1E,0x00,0x00,0x1E,0x06,0x00 ;34/ --> "
	db	0x00,0x14,0x3E,0x14,0x3E,0x14,0x00,0x00 ;35/ --> #
	db	0x00,0x04,0x26,0xEB,0x32,0x10,0x00,0x00 ;36/ --> $
	db	0x40,0x66,0x36,0x18,0x6C,0x66,0x02,0x00 ;37/ --> %
	db	0x00,0x00,0x36,0x49,0x55,0x22,0x40,0x00 ;38/ --> &
	db	0x00,0x00,0x00,0x0B,0x07,0x00,0x00,0x00 ;39/ --> '
	db	0x00,0x00,0x1C,0x3E,0x41,0x00,0x00,0x00 ;40/ --> (
	db	0x00,0x00,0x41,0x3E,0x1C,0x00,0x00,0x00 ;41/ --> )
	db	0x00,0x22,0x1C,0x3E,0x1C,0x22,0x00,0x00 ;42/ --> *
	db	0x00,0x08,0x08,0x3E,0x08,0x08,0x00,0x00 ;43/ --> +
	db	0x00,0x00,0x00,0xB0,0x70,0x00,0x00,0x00 ;44/ --> ,
	db	0x00,0x08,0x08,0x08,0x08,0x08,0x08,0x00 ;45/ --> -
	db	0x00,0x00,0x00,0xE0,0xE0,0xE0,0x00,0x00 ;46/ --> .
	db	0x00,0x40,0x20,0x10,0x08,0x04,0x02,0x00 ;47/ --> /
	db	0x00,0x3E,0x51,0x49,0x45,0x3E,0x00,0x00 ;48/ --> 0
	db	0x00,0x42,0x42,0x7F,0x40,0x40,0x00,0x00 ;49/ --> 1
	db	0x00,0x00,0x62,0x51,0x49,0x46,0x00,0x00 ;50/ --> 2
	db	0x22,0x41,0x49,0x49,0x49,0x36,0x00,0x00 ;51/ --> 3
	db	0x00,0x10,0x18,0x14,0x12,0x7F,0x10,0x00 ;52/ --> 4
	db	0x00,0x26,0x45,0x45,0x45,0x45,0x39,0x00 ;53/ --> 5
	db	0x00,0x3E,0x49,0x49,0x49,0x49,0x32,0x00 ;54/ --> 6
	db	0x00,0x01,0x01,0x71,0x09,0x05,0x03,0x00 ;55/ --> 7
	db	0x00,0x36,0x49,0x49,0x49,0x36,0x00,0x00 ;56/ --> 8
	db	0x00,0x46,0x49,0x49,0x49,0x3E,0x00,0x00 ;57/ --> 9
	db	0x00,0x00,0x00,0x36,0x36,0x00,0x00,0x00 ;58/ --> :
	db	0x00,0x00,0x00,0xB6,0x76,0x00,0x00,0x00 ;59/ --> ;
	db	0x00,0x00,0x08,0x1C,0x22,0x41,0x00,0x00 ;60/ --> <
	db	0x00,0x24,0x24,0x24,0x24,0x24,0x00,0x00 ;61/ --> =
	db	0x00,0x00,0x41,0x22,0x1C,0x08,0x00,0x00 ;62/ --> >
	db	0x02,0x03,0xD1,0xD9,0x07,0x02,0x00,0x00 ;63/ --> ?
	db	0x00,0x00,0x64,0x92,0xF2,0x82,0x7C,0x00 ;64/ --> @
	db	0x00,0x7C,0x7E,0x11,0x11,0x7E,0x7C,0x00 ;65/ --> A
	db	0x00,0x7F,0x7F,0x49,0x49,0x4E,0x30,0x00 ;66/ --> B
	db	0x00,0x1C,0x3E,0x63,0x41,0x63,0x22,0x00 ;67/ --> C
	db	0x00,0x7F,0x7F,0x41,0x41,0x3E,0x1C,0x00 ;68/ --> D
	db	0x00,0x7F,0x7F,0x49,0x49,0x49,0x41,0x00 ;69/ --> E
	db	0x00,0x7F,0x7F,0x09,0x09,0x09,0x01,0x00 ;70/ --> F
	db	0x1C,0x3E,0x41,0x49,0x79,0x38,0x00,0x00 ;71/ --> G
	db	0x00,0x7F,0x7F,0x08,0x08,0x7F,0x7F,0x00 ;72/ --> H
	db	0x00,0x00,0x41,0x7F,0x7F,0x41,0x00,0x00 ;73/ --> I
	db	0x20,0x60,0x40,0x40,0x7F,0x3F,0x00,0x00 ;74/ --> J
	db	0xFF,0xFF,0x18,0x3C,0x66,0xC3,0x81,0x00 ;75/ --> K
	db	0x00,0x7F,0x7F,0x40,0x40,0x40,0x40,0x00 ;76/ --> L
	db	0x7F,0x7F,0x06,0x0C,0x0C,0x06,0x7F,0x7F ;77/ --> M
	db	0x00,0x7F,0x7F,0x0C,0x18,0x7F,0x7F,0x00 ;78/ --> N
	db	0x00,0x1C,0x3E,0x41,0x41,0x3E,0x1C,0x00 ;79/ --> O
	db	0x00,0x7F,0x7F,0x09,0x09,0x0F,0x06,0x00 ;80/ --> P
	db	0x00,0x1C,0x3E,0x41,0x71,0x7E,0x5C,0x00 ;81/ --> Q
	db	0x00,0x7F,0x7F,0x19,0x39,0x6F,0x46,0x00 ;82/ --> R
	db	0x00,0x26,0x6F,0x49,0x49,0x7B,0x32,0x00 ;83/ --> S
	db	0x00,0x01,0x01,0x7F,0x7F,0x01,0x01,0x00 ;84/ --> T
	db	0x00,0x3F,0x7F,0x40,0x40,0x7F,0x3F,0x00 ;85/ --> U
	db	0x00,0x1F,0x3F,0x60,0x60,0x3F,0x1F,0x00 ;86/ --> V
	db	0x1F,0x3F,0x70,0x18,0x18,0x70,0x3F,0x1F ;87/ --> W
	db	0x41,0x63,0x1C,0x1C,0x63,0x41,0x00,0x00 ;88/ --> X
	db	0x00,0x01,0x07,0x7C,0x7C,0x07,0x01,0x00 ;89/ --> Y
	db	0x00,0x61,0x71,0x59,0x4D,0x47,0x43,0x00 ;90/ --> Z
	db	0x00,0x00,0x7F,0x7F,0x41,0x41,0x00,0x00 ;91/ --> [
	db	0x00,0x02,0x06,0x0C,0x18,0x30,0x20,0x00 ;92/ --> \
	db	0x00,0x00,0x41,0x41,0x7F,0x7F,0x00,0x00 ;93/ --> ]
	db	0x00,0x0C,0x06,0x03,0x03,0x06,0x0C,0x00 ;94/ --> ^
	db	0x00,0xC0,0xC0,0xC0,0xC0,0xC0,0xC0,0x00 ;95/ --> _
	db	0x00,0x00,0x00,0x07,0x0B,0x00,0x00,0x00 ;96/ --> `
	db	0x00,0x20,0x70,0x54,0x54,0x7C,0x78,0x00 ;97/ --> a
	db	0x00,0x7F,0x7F,0x48,0x44,0x7C,0x38,0x00 ;98/ --> b
	db	0x00,0x38,0x7C,0x44,0x44,0x28,0x00,0x00 ;99/ --> c
	db	0x00,0x30,0x78,0x44,0x44,0x7F,0x7F,0x00 ;100/ --> d
	db	0x00,0x18,0x3C,0x4A,0x4A,0x2C,0x00,0x00 ;101/ --> e
	db	0x00,0xFC,0xFE,0x11,0x01,0x06,0x00,0x00 ;102/ --> f
	db	0x00,0x40,0x8C,0x92,0x92,0xFE,0x7C,0x00 ;103/ --> g
	db	0x00,0x00,0xFE,0xFE,0x30,0x30,0xE0,0x00 ;104/ --> h
	db	0x00,0x00,0x00,0x7B,0xFB,0x80,0x40,0x00 ;105/ --> i
	db	0x00,0x00,0x40,0x80,0xC8,0x7B,0x3B,0x00 ;106/ --> j
	db	0x00,0xFF,0xFF,0x30,0x78,0x84,0x84,0x00 ;107/ --> k
	db	0x00,0x00,0xFF,0xFF,0x80,0x00,0x00,0x00 ;108/ --> l
	db	0x00,0xF8,0xF8,0x10,0xF0,0x10,0xE0,0x00 ;109/ --> m
	db	0x00,0xF8,0xF8,0x10,0x10,0xE0,0x00,0x00 ;110/ --> n
	db	0x00,0x70,0xF8,0x88,0x88,0xF8,0x70,0x00 ;111/ --> o
	db	0x00,0x00,0xFC,0xFC,0x24,0x24,0x18,0x00 ;112/ --> p
	db	0x00,0x18,0x24,0x24,0xFC,0xFC,0x00,0x00 ;113/ --> q
	db	0x00,0x00,0xFC,0xFC,0x18,0x08,0x18,0x00 ;114/ --> r
   	db	0x00,0x48,0x54,0x54,0x54,0x20,0x00,0x00 ;115/ --> s
	db	0x00,0x00,0x10,0xFC,0xFC,0x90,0x00,0x00 ;116/ --> t
	db	0x00,0x78,0xF8,0xC0,0x40,0xF8,0x80,0x00 ;117/ --> u
	db	0x00,0x18,0x38,0xC0,0xC0,0x38,0x18,0x00 ;118/ --> v
	db	0x38,0x78,0xC0,0x60,0x60,0xC0,0x78,0x38 ;119/ --> w
	db	0x00,0x48,0x78,0x30,0x78,0x48,0x00,0x00 ;120/ --> x
	db	0x00,0x40,0x8C,0x90,0xF0,0x7C,0x00,0x00 ;121/ --> y
	db	0x00,0x88,0xC8,0xE8,0xB8,0x98,0x00,0x00 ;122/ --> z
	db	0x00,0x00,0x10,0x6C,0x82,0x00,0x00,0x00 ;123/ --> {
	db	0x00,0x00,0x00,0xE7,0xE7,0x00,0x00,0x00 ;124/ --> |
	db	0x00,0x00,0x00,0x82,0x6C,0x10,0x00,0x00 ;125/ --> }
	db	0x00,0x10,0x08,0x08,0x08,0x08,0x04,0x00 ;126/ --> ~
	db	0x00,0x78,0x44,0x46,0x46,0x44,0x78,0x00 ;127/ --> 





   
font3

;    Mono Spaced - Bold Serif

     db 0x00,0x00,0x00,0x00,0x00,0x00,0x00    ; ' '
     db 0x00,0x06,0x5F,0x5F,0x06,0x00,0x00    ; '!'
     db 0x00,0x07,0x07,0x00,0x07,0x07,0x00    ; '"'
     db 0x14,0x7F,0x7F,0x14,0x7F,0x7F,0x14    ; '#'
     db 0x24,0x2E,0x6B,0x6B,0x3A,0x12,0x00    ; '$'
     db 0x46,0x66,0x30,0x18,0x0C,0x66,0x62    ; '%'
     db 0x30,0x7A,0x4F,0x5D,0x37,0x7A,0x48    ; '&'
     db 0x04,0x07,0x03,0x00,0x00,0x00,0x00    ; '''
     db 0x00,0x1C,0x3E,0x63,0x41,0x00,0x00    ; '('
     db 0x00,0x41,0x63,0x3E,0x1C,0x00,0x00    ; ')'
     db 0x08,0x2A,0x3E,0x1C,0x1C,0x3E,0x2A    ; '*'
     db 0x08,0x08,0x3E,0x3E,0x08,0x08,0x00    ; '+'
     db 0x00,0x80,0xE0,0x60,0x00,0x00,0x00    ; ','
     db 0x08,0x08,0x08,0x08,0x08,0x08,0x00    ; '-'
     db 0x00,0x00,0x60,0x60,0x00,0x00,0x00    ; '.'
     db 0x60,0x30,0x18,0x0C,0x06,0x03,0x01    ; '/'
     db 0x3E,0x7F,0x71,0x59,0x4D,0x7F,0x3E    ; '0'
     db 0x40,0x42,0x7F,0x7F,0x40,0x40,0x00    ; '1'
     db 0x62,0x73,0x59,0x49,0x6F,0x66,0x00    ; '2'
     db 0x22,0x63,0x49,0x49,0x7F,0x36,0x00    ; '3'
     db 0x18,0x1C,0x16,0x53,0x7F,0x7F,0x50    ; '4'
     db 0x27,0x67,0x45,0x45,0x7D,0x39,0x00    ; '5'
     db 0x3C,0x7E,0x4B,0x49,0x79,0x30,0x00    ; '6'
     db 0x03,0x03,0x71,0x79,0x0F,0x07,0x00    ; '7'
     db 0x36,0x7F,0x49,0x49,0x7F,0x36,0x00    ; '8'
     db 0x06,0x4F,0x49,0x69,0x3F,0x1E,0x00    ; '9'
     db 0x00,0x00,0x66,0x66,0x00,0x00,0x00    ; ':'
     db 0x00,0x80,0xE6,0x66,0x00,0x00,0x00    ; ';'
     db 0x08,0x1C,0x36,0x63,0x41,0x00,0x00    ; '<'
     db 0x24,0x24,0x24,0x24,0x24,0x24,0x00    ; '='
     db 0x00,0x41,0x63,0x36,0x1C,0x08,0x00    ; '>'
     db 0x02,0x03,0x51,0x59,0x0F,0x06,0x00    ; '?'
     db 0x3E,0x7F,0x41,0x5D,0x5D,0x1F,0x1E    ; '@'
     db 0x7C,0x7E,0x13,0x13,0x7E,0x7C,0x00    ; 'A'
     db 0x41,0x7F,0x7F,0x49,0x49,0x7F,0x36    ; 'B'
     db 0x1C,0x3E,0x63,0x41,0x41,0x63,0x22    ; 'C'
     db 0x41,0x7F,0x7F,0x41,0x63,0x3E,0x1C    ; 'D'
     db 0x41,0x7F,0x7F,0x49,0x5D,0x41,0x63    ; 'E'
     db 0x41,0x7F,0x7F,0x49,0x1D,0x01,0x03    ; 'F'
     db 0x1C,0x3E,0x63,0x41,0x51,0x73,0x72    ; 'G'
     db 0x7F,0x7F,0x08,0x08,0x7F,0x7F,0x00    ; 'H'
     db 0x00,0x41,0x7F,0x7F,0x41,0x00,0x00    ; 'I'
     db 0x30,0x70,0x40,0x41,0x7F,0x3F,0x01    ; 'J'
     db 0x41,0x7F,0x7F,0x08,0x1C,0x77,0x63    ; 'K'
     db 0x41,0x7F,0x7F,0x41,0x40,0x60,0x70    ; 'L'
     db 0x7F,0x7F,0x0E,0x1C,0x0E,0x7F,0x7F    ; 'M'
     db 0x7F,0x7F,0x06,0x0C,0x18,0x7F,0x7F    ; 'N'
     db 0x1C,0x3E,0x63,0x41,0x63,0x3E,0x1C    ; 'O'
     db 0x41,0x7F,0x7F,0x49,0x09,0x0F,0x06    ; 'P'
     db 0x1E,0x3F,0x21,0x71,0x7F,0x5E,0x00    ; 'Q'
     db 0x41,0x7F,0x7F,0x09,0x19,0x7F,0x66    ; 'R'
     db 0x26,0x6F,0x4D,0x59,0x73,0x32,0x00    ; 'S'
     db 0x03,0x41,0x7F,0x7F,0x41,0x03,0x00    ; 'T'
     db 0x7F,0x7F,0x40,0x40,0x7F,0x7F,0x00    ; 'U'
     db 0x1F,0x3F,0x60,0x60,0x3F,0x1F,0x00    ; 'V'
     db 0x7F,0x7F,0x30,0x18,0x30,0x7F,0x7F    ; 'W'
     db 0x43,0x67,0x3C,0x18,0x3C,0x67,0x43    ; 'X'
     db 0x07,0x4F,0x78,0x78,0x4F,0x07,0x00    ; 'Y'
     db 0x47,0x63,0x71,0x59,0x4D,0x67,0x73    ; 'Z'
     db 0x00,0x7F,0x7F,0x41,0x41,0x00,0x00    ; '['
     db 0x01,0x03,0x06,0x0C,0x18,0x30,0x60    ; '\'
     db 0x00,0x41,0x41,0x7F,0x7F,0x00,0x00    ; ']'
     db 0x08,0x0C,0x06,0x03,0x06,0x0C,0x08    ; '^'
     db 0x80,0x80,0x80,0x80,0x80,0x80,0x80    ; '_'
     db 0x00,0x00,0x03,0x07,0x04,0x00,0x00    ; '`'
     db 0x20,0x74,0x54,0x54,0x3C,0x78,0x40    ; 'a'
     db 0x41,0x7F,0x3F,0x48,0x48,0x78,0x30    ; 'b'
     db 0x38,0x7C,0x44,0x44,0x6C,0x28,0x00    ; 'c'
     db 0x30,0x78,0x48,0x49,0x3F,0x7F,0x40    ; 'd'
     db 0x38,0x7C,0x54,0x54,0x5C,0x18,0x00    ; 'e'
     db 0x48,0x7E,0x7F,0x49,0x03,0x02,0x00    ; 'f'
     db 0x38,0xBC,0xA4,0xA4,0xFC,0x78,0x00    ; 'g'
     db 0x41,0x7F,0x7F,0x08,0x04,0x7C,0x78    ; 'h'
     db 0x00,0x44,0x7D,0x7D,0x40,0x00,0x00    ; 'i'
     db 0x60,0xE0,0x80,0x80,0xFD,0x7D,0x00    ; 'j'
     db 0x41,0x7F,0x7F,0x10,0x38,0x6C,0x44    ; 'k'
     db 0x00,0x41,0x7F,0x7F,0x40,0x00,0x00    ; 'l'
     db 0x78,0x7C,0x1C,0x38,0x1C,0x7C,0x78    ; 'm'
     db 0x7C,0x7C,0x04,0x04,0x7C,0x78,0x00    ; 'n'
     db 0x38,0x7C,0x44,0x44,0x7C,0x38,0x00    ; 'o'
     db 0x00,0xFC,0xFC,0xA4,0x24,0x3C,0x18    ; 'p'
     db 0x18,0x3C,0x24,0xA4,0xF8,0xFC,0x84    ; 'q'
     db 0x44,0x7C,0x78,0x4C,0x04,0x1C,0x18    ; 'r'
     db 0x48,0x5C,0x54,0x54,0x74,0x24,0x00    ; 's'
     db 0x00,0x04,0x3E,0x7F,0x44,0x24,0x00    ; 't'
     db 0x3C,0x7C,0x40,0x40,0x3C,0x7C,0x40    ; 'u'
     db 0x1C,0x3C,0x60,0x60,0x3C,0x1C,0x00    ; 'v'
     db 0x3C,0x7C,0x70,0x38,0x70,0x7C,0x3C    ; 'w'
     db 0x44,0x6C,0x38,0x10,0x38,0x6C,0x44    ; 'x'
     db 0x3C,0xBC,0xA0,0xA0,0xFC,0x7C,0x00    ; 'y'
     db 0x4C,0x64,0x74,0x5C,0x4C,0x64,0x00    ; 'z'
     db 0x08,0x08,0x3E,0x77,0x41,0x41,0x00    ; '{'
     db 0x00,0x00,0x00,0x77,0x77,0x00,0x00    ; '|'
     db 0x41,0x41,0x77,0x3E,0x08,0x08,0x00    ; '}'
     db 0x02,0x03,0x01,0x03,0x02,0x03,0x01    ; '~'
     db 0xFF,0x81,0x81,0x81,0x81,0x81,0xFF    ; ''
     db 0x0E,0x9F,0x91,0xB1,0xFB,0x4A,0x00    ; 


 
 


;****************************************************************************************
;
;  Full Screen 128x64 converted BitMap Images
;  ==========================================

; MCDog.bmp (128 x 64)


eadog

	db	0xFF,0x01,0x01,0x01,0x01,0x01,0xFF,0x00,0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x7F
	db	0x40,0x40,0x40,0x40,0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x3E,0x41,0x41,0x41,0x22
	db	0x00,0x01,0x01,0x7F,0x01,0x01,0x00,0x7F,0x09,0x19,0x29,0x46,0x00,0x3E,0x41,0x41
	db	0x41,0x3E,0x00,0x7F,0x04,0x08,0x10,0x7F,0x00,0x41,0x7F,0x41,0x00,0x3E,0x41,0x41
	db	0x41,0x22,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0xFF,0x0F,0x0F,0x0F,0x1F,0xFE,0xFE
	db	0xFC,0xF0,0x00,0x00,0xF0,0xFC,0xFE,0xFE,0x1F,0x0F,0x0F,0x0F,0x0F,0x1F,0xFE,0xFE
	db	0xFC,0xF0,0x00,0x00,0xF0,0xFC,0xFE,0xFE,0x1F,0x0F,0xCF,0xEF,0xEF,0xEF,0xEF,0xE6
	db	0xC0,0x00,0xC0,0xC0,0xC0,0xC0,0x00,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFC,0xFC,0xFC,0xFC,0xFC,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7E
	db	0x11,0x11,0x11,0x7E,0x00,0x46,0x49,0x49,0x49,0x31,0x00,0x46,0x49,0x49,0x49,0x31
	db	0x00,0x7F,0x49,0x49,0x49,0x41,0x00,0x7F,0x02,0x0C,0x02,0x7F,0x00,0x7F,0x49,0x49
	db	0x49,0x36,0x00,0x7F,0x40,0x40,0x40,0x40,0x07,0x08,0x70,0x08,0x07,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x3F,0x3F,0x3F,0x3C,0x3C,0x3C,0x3E,0x1F,0x1F
	db	0x0F,0x03,0x00,0x00,0x03,0x0F,0x1F,0x1F,0x3E,0x3C,0x3C,0x3C,0x3C,0x1E,0x1F,0x1F
	db	0x0F,0x03,0x00,0x00,0x03,0x0F,0x1F,0x1F,0x3E,0x3C,0x3C,0x3D,0x3D,0x3F,0x1F,0x1F
	db	0x07,0x00,0x01,0x01,0x01,0x01,0x00,0x3F,0x3F,0x3F,0x38,0x38,0x38,0x38,0x38,0x38
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x20,0x40,0x80,0x00,0x00,0x00
	db	0x00,0x00,0x3F,0x00,0x00,0x00,0x00,0x80,0x40,0x20,0x10,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x10,0x30,0x50,0x90,0x20,0x40,0xC0,0x80,0x00,0x00,0x00,0x00
	db	0x00,0xC0,0x30,0x08,0x80,0x78,0x40,0x20,0x14,0x8A,0xC0,0xA6,0x50,0x28,0x20,0xC4
	db	0x02,0x02,0x04,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10,0x10,0x00,0x00,0x00,0x70,0x88,0x04
	db	0x02,0xE2,0x22,0x02,0x04,0x88,0x70,0x00,0x00,0x00,0x10,0x10,0x10,0x10,0x10,0x10
	db	0x10,0x10,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x02,0x06,0x0A,0x0A,0x12,0x24,0x45,0x8A,0x14,0xB8,0x61,0x42,0x84,0x0C
	db	0x1F,0x30,0xE0,0x00,0x00,0x00,0x08,0x06,0x03,0x61,0x30,0x28,0x94,0x4E,0xB5,0x84
	db	0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x60,0x80,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x08,0x04,0x02,0x00,0x00,0x00,0x00,0x01
	db	0x7E,0xFF,0xFE,0x7E,0x01,0x00,0x00,0x00,0x00,0x02,0x04,0x08,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0x6E,0x31
	db	0x12,0x14,0x18,0x18,0x08,0x08,0x08,0x04,0x06,0x03,0x02,0x01,0x84,0x80,0x44,0x01
	db	0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x40,0x40,0x43,0x22,0x11,0x08,0x04
	db	0x03,0x00,0x00,0xE0,0x10,0x00,0x00,0x00,0x00,0x00,0x03,0x8C,0x10,0x60,0x80,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x08,0xFC,0x00,0x00,0x08,0x84,0x44,0x24,0x18,0x00,0xD8,0x24,0x24,0x24
	db	0xD8,0x00,0x10,0xA0,0x40,0xA0,0x10,0x00,0xF0,0x28,0x24,0x24,0xC0,0x00,0x60,0x50
	db	0x48,0xFC,0x40,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x04,0x06
	db	0x0E,0x0A,0x12,0x14,0x14,0x14,0x14,0x12,0x12,0x12,0x11,0x11,0x88,0x48,0x38,0x18
	db	0x18,0x1C,0x34,0x64,0x64,0xC8,0xF8,0x0F,0x00,0x00,0x00,0x00,0x04,0xF8,0x10,0x90
	db	0x88,0x88,0x7F,0x60,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x18,0xEF,0x88,0x10,0x11
	db	0x22,0x44,0x48,0x50,0x90,0xA0,0x20,0x20,0x20,0xA0,0x60,0x00,0x00,0x00,0x00,0x00
	db	0x10,0x10,0xB8,0x90,0x90,0x90,0x8C,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x01,0x01,0x00,0x00,0x00,0x01,0x01,0x01
	db	0x00,0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,0x01,0x01,0x01,0x00,0x00,0x00,0x00
	db	0x00,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x0D,0x08,0x1E,0x11,0x18
	db	0x08,0x18,0x18,0x14,0x33,0x31,0x2C,0x20,0x30,0x38,0x20,0x20,0x20,0x17,0x1D,0x01
	db	0x00,0x00,0x10,0x2C,0x22,0x33,0x3C,0x20,0x30,0x28,0x20,0x20,0x27,0x1C,0x01,0x03
	db	0x02,0x02,0x02,0x02,0x02,0x02,0x01,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0xE0,0x93,0x90,0xE3,0x94,0x94,0xE3,0x00,0x00,0x00,0x00,0x00,0xFE,0x12,0x12,0x12
	db	0x0C,0x00,0x82,0xFE,0x82,0x00,0x7C,0x82,0x82,0x82,0x44,0x00,0x00,0x00,0x00,0x00
	db	0xFE,0x00,0x6C,0x92,0x92,0x92,0x6C,0x00,0xFE,0x12,0x12,0x12,0x02,0x00,0x00,0x00
	db	0x00,0x00,0x0C,0x92,0x92,0x92,0x60,0x00,0xFE,0x12,0x12,0x12,0x0C,0x00,0x82,0xFE
	db	0x82,0x00,0x00,0x00,0x00,0x00,0xFC,0x22,0x22,0x22,0xFC,0x00,0x0C,0x92,0x92,0x92
	db	0x60,0x00,0x0C,0x92,0x92,0x92,0x60,0x00,0xFE,0x92,0x92,0x92,0x92,0x00,0xFE,0x04
	db	0x08,0x04,0xFE,0x00,0xFE,0x92,0x92,0x92,0x6C,0x00,0xFE,0x80,0x80,0x80,0x80,0x00
	db	0xFE,0x92,0x92,0x92,0x92,0x00,0xFE,0x12,0x32,0x52,0x8C,0x00,0x00,0x00,0x00,0x00





;C:\Downloads\BMP2ASM\SETTEMP.bmp (128 x 64)


gmenu

	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0xC0,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0xC0,0x00,0x00,0x00,0x00,0x00,0xC0,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0xC0,0x00,0x00,0x00,0x00,0x00,0xC0,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40
	db	0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,0xC0,0x00,0x00,0x00
	db	0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,0x60,0x30,0x18
	db	0x0C,0x04,0x06,0xFF,0xFF,0x06,0x04,0x0C,0x18,0x30,0x60,0x40,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0xC0,0x30,0x10,0x08,0x08,0x04,0x04,0x04,0x04,0x04,0x04,0x04
	db	0x04,0x04,0x04,0x04,0x04,0x08,0x08,0x10,0x30,0xC0,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00
	db	0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x0F,0x30,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x0E,0x11,0x11
	db	0x11,0x0E,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0x30,0x0F,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00
	db	0x00,0x00,0x08,0x18,0x30,0x60,0xC0,0x80,0x80,0xFF,0xFF,0x80,0x80,0xC0,0x60,0x30
	db	0x18,0x08,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xFF,0x00,0x00,0x00
	db	0x00,0x00,0x00,0x3F,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20
	db	0x20,0x20,0x20,0x23,0x23,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20
	db	0x20,0x20,0x20,0x20,0x20,0x20,0x3F,0x00,0x00,0x00,0x00,0x00,0x3F,0x20,0x20,0x20
	db	0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x21,0x21,0x22,0x22,0x22,0x22,0x22,0x22,0x22
	db	0x22,0x22,0x22,0x22,0x22,0x21,0x21,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20
	db	0x20,0x20,0x3F,0x00,0x00,0x00,0x00,0x00,0x3F,0x20,0x20,0x20,0x20,0x20,0x20,0x20
	db	0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x21,0x23,0x23,0x21,0x20,0x20,0x20,0x20
	db	0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x3F,0x00,0x00,0x00



; ***************************************************************************************

	END

; ***************************************************************************************
; ***************************************************************************************
